# This file was auto-generated by Fern from our API Definition.

import typing

from .cloud_chroma_vector_store import CloudChromaVectorStore
from .cloud_pinecone_vector_store import CloudPineconeVectorStore
from .cloud_postgres_vector_store import CloudPostgresVectorStore
from .cloud_qdrant_vector_store import CloudQdrantVectorStore
from .cloud_weaviate_vector_store import CloudWeaviateVectorStore

DataSinkComponentOne = typing.Union[
    CloudChromaVectorStore,
    CloudPineconeVectorStore,
    CloudPostgresVectorStore,
    CloudQdrantVectorStore,
    CloudWeaviateVectorStore,
]
