# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.cloud_chroma_vector_store import CloudChromaVectorStore
from ....types.cloud_pinecone_vector_store import CloudPineconeVectorStore
from ....types.cloud_postgres_vector_store import CloudPostgresVectorStore
from ....types.cloud_qdrant_vector_store import CloudQdrantVectorStore
from ....types.cloud_weaviate_vector_store import CloudWeaviateVectorStore

DataSinkUpdateComponentOne = typing.Union[
    CloudChromaVectorStore,
    CloudPineconeVectorStore,
    CloudPostgresVectorStore,
    CloudQdrantVectorStore,
    CloudWeaviateVectorStore,
]
