# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.document import Document
from ....types.reader_config import ReaderConfig
from ....types.text_node import TextNode

DataSourceUpdateComponentOne = typing.Union[ReaderConfig, typing.Any, TextNode, Document]
